<?php

/**
 * @file
 * ji_oauth_handshake.inc
 *
 * A callback used by QBO to exchange token information. Enabled by
 * ji_quickbooks.module in its hook_menu(). The link to access this page
 * is sent to QBO via the js/ji_oauth_authorize_runnable.js code.
 */

/**
 * Called by ji_quickbooks.module hook_menu().
 *
 * It's nice because we use Drupal's access arguments
 * to prevent outside access.
 */
function ji_oauth_handshake() {
  $oauth_request_url = 'https://oauth.intuit.com/oauth/v1/get_request_token';
  $oauth_access_url = 'https://oauth.intuit.com/oauth/v1/get_access_token';
  $oauth_authorize_url = 'https://appcenter.intuit.com/Connect/Begin';

  global $base_url;

  // Make sure this CALLBACK_URL points back to this page or
  // hook_menu's /ji_oauth_handshake.
  define('CALLBACK_URL', $base_url . '/ji_oauth_handshake');

  // Cleans out the token variable if coming from the
  // 'connect to QuickBooks' button.
  if (filter_input(INPUT_GET, 'start')) {
    unset($_SESSION['token']);
  }

  try {
    $consumer_key = variable_get('ji_quickbooks_settings_consumer_key', '');
    $consumer_secret = variable_get('ji_quickbooks_settings_consumer_secret', '');

    $oauth = new OAuth($consumer_key, $consumer_secret, OAUTH_SIG_METHOD_HMACSHA1, OAUTH_AUTH_TYPE_URI);
    // To avoid the error: (Peer certificate cannot be
    // authenticated with given CA certificates).
    $oauth->disableSSLChecks();

    $oauth_token = filter_input(INPUT_GET, 'oauth_token');

    if (!$oauth_token && !isset($_SESSION['token'])) {
      // Step 1: get request token from Intuit.
      $request_token = $oauth->getRequestToken($oauth_request_url, CALLBACK_URL);
      $_SESSION['secret'] = $request_token['oauth_token_secret'];
      // Step 2: send user to intuit to authorize.
      header('Location: ' . $oauth_authorize_url . '?oauth_token=' . $request_token['oauth_token']);
    }

    if ($oauth_token && filter_input(INPUT_GET, 'oauth_verifier')) {
      // Step 3: request a access token from Intuit.
      $oauth->setToken($oauth_token, $_SESSION['secret']);
      $access_token = $oauth->getAccessToken($oauth_access_url);

      $_SESSION['token'] = serialize($access_token);
      // 'realmId' is legacy for customerId.
      $_SESSION['realmId'] = $_REQUEST['realmId'];
      $_SESSION['dataSource'] = $_REQUEST['dataSource'];

      // Write JS to pop up to refresh parent and close popup.
      echo '<script type="text/javascript">
            window.opener.location.href = window.opener.location.href;
            window.close();
          </script>';
    }
  }
  catch (OAuthException $e) {
    watchdog('JI QuickBooks', $e->getMessage(), NULL, WATCHDOG_CRITICAL);
  }
}
