<?php

/**
 * @file
 * ji_oauth_authorize.tpl.php
 *
 * Template file called from ji_quickbooks.module. Responsible for providing
 * a simple interface where an authorized user can connect Drupal to QBO.
 */

global $base_url;
$openid = new LightOpenID($base_url);
?>
<?php if (!$openid->mode) : ?>
  <div>
      To be listed on QuickBooks Apps.com, any app must implement OpenID for user authentication.
  </div>
  <br>
  <?php
  $connectWithIntuitOpenId = filter_input(INPUT_GET, 'connectWithIntuitOpenId');
  $subscribeFromAppsDotCom = filter_input(INPUT_GET, 'subscribeFromAppsDotCom');
  ?>
  <?php if (isset($connectWithIntuitOpenId) || isset($subscribeFromAppsDotCom)) : ?>
    <?php
    $openid->identity = "https://openid.intuit.com/Identity-me";
    // The following two lines request email and full name
    // from the Intuit OpenID provider.
    $openid->required = array('contact/email');
    $openid->optional = array('namePerson', 'namePerson/friendly');
    header('Location: ' . $openid->authUrl());
    ?>
  <?php else : ?>
    <div>
        <ipp:login href="?connectWithIntuitOpenId" type="vertical">
    </div>
  <?php endif; ?>
<?php elseif ($openid->mode == 'cancel') : ?>
  <h2>User has canceled authentication!</h2>
<?php else : ?>
  <br/>
  <?php
  // After the oauth process the oauth token and secret
  // are stored in session variables.
  ?>
  <?php if (!isset($_SESSION['token'])) : ?>
    <h3>You are not currently authenticated!</h3>
    <div>
        Click on the button below to connect this app to QuickBooks.
    </div>
    <br />
    <?php
    // Display the QuickBooks button.
    ?>
    <ipp:connectToIntuit></ipp:connectToIntuit>
    <br/>
  <?php else : ?>
    <h3>You are currently authenticated!</h3>
    <?php $token = unserialize($_SESSION['token']); ?>
    Access tokens and keys have been saved and you can now start using JI QuickBooks.
    <br/>
    <br/>
    Realm ID: <?php print $_SESSION['realmId']; ?><br/>
    OAuth token: <?php print $token['oauth_token']; ?><br/>
    OAuth secret: <?php print $token['oauth_token_secret']; ?><br/>
    <br/>
    <button class='myButton' title='Disconnect your app from QBO' onclick='back_to_ji_quickbooks()'>Continue Configuring JI QuickBooks</button>
    <button class='myButton' title='Disconnect your app from QBO' onclick='disconnect()'>Disconnect the app</button>
    <button class='myButton' title='Regenerate the tokens within 30 days prior to token expiration' onclick='reconnect()'>Reconnect the app</button>
    <br/>
    <br/>
    <?php
    variable_set('ji_quickbooks_settings_access_token', $token['oauth_token']);
    variable_set('ji_quickbooks_settings_access_token_secret', $token['oauth_token_secret']);
    variable_set('ji_quickbooks_settings_realm_id', $_SESSION['realmId']);
    ?>
  <?php endif; ?>
<?php endif; ?>
<?php
?>
<script>
  function back_to_ji_quickbooks() {
      window.location.href = '<?php print $base_url; ?>/admin/config/services/ji_quickbooks';
  }
  function disconnect() {
      window.location.href = '<?php print $base_url; ?>/ji_oauth_disconnect';
  }
  function reconnect() {
      window.location.href = '<?php print $base_url; ?>/ji_oauth_reconnect';
  }
</script>
